@@ -13,31 +13,25 @@ from rabbit.exchange import Exchange
 from rabbit.queue import Queue
 
 
-@attr.s(slots=True)
+@attr.s(slots=True, repr=False)
 class DLX:
     _client = attr.ib(
         type=AioRabbitClient,
         validator=attr.validators.instance_of(AioRabbitClient),
         repr=False,
     )
+    exchange = attr.ib(
+        type=Exchange,
+        validator=attr.validators.instance_of(Exchange),
+    )
+    dlq_exchange = attr.ib(
+        type=Exchange,
+        validator=attr.validators.instance_of(Exchange),
+    )
     queue = attr.ib(
         type=Queue,
-        default=Queue(
-            name=os.getenv("SUBSCRIBE_QUEUE", "default.subscribe.queue"),
-            arguments={
-                "x-dead-letter-exchange": os.getenv(
-                    "SUBSCRIBE_EXCHANGE", "default.in.exchange"
-                ),
-                "x-dead-letter-routing-key": os.getenv("SUBSCRIBE_TOPIC", "#"),
-            },
-        ),
         validator=attr.validators.instance_of(Queue),
     )
-    routing_key = attr.ib(
-        type=str,
-        default=os.getenv("SUBSCRIBE_QUEUE", "default.subscribe.queue"),
-        validator=attr.validators.instance_of(str),
-    )
     delay_strategy = attr.ib(
         type=Callable, default=constant, validator=attr.validators.is_callable()
     )
@@ -46,30 +40,32 @@ class DLX:
         default=int(os.getenv("INITIAL_DELAY", 300000)),
         validator=attr.validators.instance_of(int),
     )
-    exchange = attr.ib(
-        type=Exchange,
-        default=Exchange(
-            name=os.getenv("DLX_EXCHANGE", "DLX"),
-            exchange_type=os.getenv("DLX_TYPE", "direct"),
-        ),
-        validator=attr.validators.instance_of(Exchange),
-    )
     _channel = attr.ib(init=False, repr=False)
 
+    def __repr__(self) -> str:
+        return f"DLX(queue={self.queue}, delay_strategy={self.delay_strategy.__name__}, delay={self.delay}, exchange={self.exchange}), dlq_exchange={self.dlq_exchange}"
+
     async def configure(self) -> None:
         self._channel = await self._client.get_channel()
         try:
-            await self._configure_exchange()
             await self._configure_queue()
+            await self._configure_exchange()
             await self._configure_queue_bind()
         except AttributeNotInitialized:
             logger.debug("Waiting client initialization...DLX")
 
     async def _configure_exchange(self) -> None:
-        await self._channel.exchange_declare(
-            exchange_name=self.exchange.name,
-            type_name=self.exchange.exchange_type,
-            durable=self.exchange.durable,
+        await asyncio.gather(
+            self._channel.exchange_declare(
+                exchange_name=self.exchange.name,
+                type_name=self.exchange.exchange_type,
+                durable=self.exchange.durable,
+            ),
+            self._channel.exchange_declare(
+                exchange_name=self.dlq_exchange.name,
+                type_name=self.dlq_exchange.exchange_type,
+                durable=self.dlq_exchange.durable,
+            ),
         )
         await asyncio.sleep(2)
 
@@ -83,10 +79,17 @@ class DLX:
 
     async def _configure_queue_bind(self) -> None:
         queue_name = await self._ensure_endswith_dlq(self.queue.name)
-        await self._channel.queue_bind(
-            exchange_name=self.exchange.name,
-            queue_name=queue_name,
-            routing_key=self.routing_key,
+        await asyncio.gather(
+            self._channel.queue_bind(
+                exchange_name=self.exchange.name,
+                queue_name=queue_name,
+                routing_key=self.queue.name,
+            ),
+            self._channel.queue_bind(
+                exchange_name=self.dlq_exchange.name,
+                queue_name=self.queue.name,
+                routing_key=self.dlq_exchange.topic,
+            ),
         )
 
     async def _ensure_endswith_dlq(self, value: str) -> str:
@@ -103,7 +106,7 @@ class DLX:
         logger.debug(f"Timeout: {timeout}")
         logger.debug(
             f"Send event to dlq: [exchange: {self.exchange.name}"
-            f" | queue: {self.queue.name} | properties: {properties}]"
+            f" | routing_key: {self.queue.name} | properties: {properties}]"
         )
         try:
             await self._channel.publish(
